Mu - A Simple Python Code Editor 
================================

.. image:: https://raw.githubusercontent.com/mu-editor/mu/master/docs/logo.png

Mu is a simple code editor for beginner programmers based on extensive feedback
from teachers and learners. Having said that, Mu is for anyone who wants to use
a simple "no frills" editor.

Mu is a modal editor with modes for Adafruit's CircuitPython, the micro:bit's
version of MicroPython, PyGame Zero and standard Python 3 (including a
graphical debugger). Some of the modes make available a REPL (either
running on the connected CircuitPython or MicroPython device or as a Jupyter
based iPython session in Python3 mode).

Mu is written in Python and works on Windows, macOS, Linux and Raspberry Pi. The
project's public facing website is
`https://codewith.mu/ <https://codewith.mu/>`_. We celebrate the work done by
users of mu at `https://madewith.mu/ <https://madewith.mu/>`_.

We have `extensive developer documentation <https://mu.readthedocs.io/>`_
including a guide for
`setting up a development environment <https://mu.readthedocs.io/en/latest/setup.html>`_, 
`contributor guidelines <https://mu.readthedocs.io/en/latest/contributing.html>`_ and
`some suggested first steps <https://mu.readthedocs.io/en/latest/first-steps.html>`_.

We want our community to be a friendly place. Therefore, we expect contributors
and collaborators to follow our
`Code of Conduct <https://mu.readthedocs.io/en/latest/code_of_conduct.html>`_.
